import { Directive, ElementRef, Renderer2, Input, NgModule, TemplateRef, EventEmitter, Component, Output, ContentChild, HostListener, ChangeDetectionStrategy, HostBinding, ViewContainerRef, ContentChildren } from '@angular/core';
import { CommonModule } from '@angular/common';
import { Overlay, OverlayModule } from '@angular/cdk/overlay';
import { ComponentPortal } from '@angular/cdk/portal';
import { CdkOverlayService } from '@js-sugar/angular';

class BadgeDirective {
    constructor(_el, _renderer) {
        this._el = _el;
        this._renderer = _renderer;
        this.color = 'primary';
        this.pill = false;
    }
    ngOnInit() {
        this._renderer.addClass(this._el.nativeElement, 'badge');
    }
}
BadgeDirective.decorators = [
    { type: Directive, args: [{
                selector: '[jssBadge]',
                exportAs: 'jssBadge',
                host: {
                    '[class.bg-primary]': 'color=="primary"',
                    '[class.bg-secondary]': 'color=="secondary"',
                    '[class.bg-success]': 'color=="success"',
                    '[class.bg-danger]': 'color=="danger"',
                    '[class.bg-warning]': 'color=="warning"',
                    '[class.bg-info]': 'color=="info"',
                    '[class.bg-light]': 'color=="light"',
                    '[class.bg-dark]': 'color=="dark"',
                    '[class.rounded-pill]': 'pill',
                }
            },] }
];
BadgeDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: Renderer2 }
];
BadgeDirective.propDecorators = {
    color: [{ type: Input, args: ['jssBadge',] }],
    pill: [{ type: Input }]
};

class BadgeModule {
}
BadgeModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    BadgeDirective
                ],
                exports: [
                    BadgeDirective
                ]
            },] }
];

class BreadcrumbItemTemplateDirective {
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
}
BreadcrumbItemTemplateDirective.decorators = [
    { type: Directive, args: [{
                selector: '[jssBreadcrumbItemTemplate]',
                exportAs: 'jssBreadcrumbItemTemplate',
            },] }
];
BreadcrumbItemTemplateDirective.ctorParameters = () => [
    { type: TemplateRef }
];

class BreadcrumbComponent {
    constructor(_el, _renderer) {
        this._el = _el;
        this._renderer = _renderer;
        this.itemClick = new EventEmitter();
    }
    ngOnInit() {
        this._renderer.setAttribute(this._el.nativeElement, 'role', 'navigation');
    }
}
BreadcrumbComponent.decorators = [
    { type: Component, args: [{
                selector: 'jss-breadcrumb',
                exportAs: 'jssBreadcrumb',
                template: "<nav aria-label=\"breadcrumb\">\r\n    <ol class=\"breadcrumb\">\r\n        <li\r\n            *ngFor=\"let item of items\"\r\n            [class.text-muted]=\"item.disabled\"\r\n            [class.active]=\"!item.disabled && item.active\"\r\n            (click)=\"item.disabled ? 0 : itemClick.emit({item: item, event: $event})\"\r\n            class=\"breadcrumb-item\">\r\n\r\n            <ng-container *ngIf=\"_itemTemplate\" [ngTemplateOutlet]=\"_itemTemplate.templateRef\"\r\n                          [ngTemplateOutletContext]=\"{$implicit: item}\">\r\n            </ng-container>\r\n            {{item.text}}\r\n        </li>\r\n    </ol>\r\n</nav>\r\n",
                styles: [':host {display: block;}']
            },] }
];
BreadcrumbComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: Renderer2 }
];
BreadcrumbComponent.propDecorators = {
    items: [{ type: Input }],
    itemClick: [{ type: Output }],
    _itemTemplate: [{ type: ContentChild, args: [BreadcrumbItemTemplateDirective,] }]
};

class BreadcrumbModule {
}
BreadcrumbModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                ],
                declarations: [
                    BreadcrumbComponent,
                    BreadcrumbItemTemplateDirective
                ],
                exports: [
                    BreadcrumbComponent,
                    BreadcrumbItemTemplateDirective
                ]
            },] }
];

class ButtonDirective {
    constructor(_element, _renderer) {
        this._element = _element;
        this._renderer = _renderer;
        this.size = 'default';
        this.kind = 'primary';
        this.safeClick = new EventEmitter();
    }
    ngOnInit() {
        this._renderer.addClass(this._element.nativeElement, 'btn');
    }
    _onClick(e) {
        if (!this.disabled) {
            this.safeClick.emit(e);
        }
    }
}
ButtonDirective.decorators = [
    { type: Directive, args: [{
                selector: 'button[jssButton], a[jssButton], input[jssButton]',
                exportAs: 'jssButton',
                host: {
                    '[class.disabled]': 'disabled',
                    '[class.btn-primary]': '!outline && kind=="primary"',
                    '[class.btn-secondary]': '!outline && kind=="secondary"',
                    '[class.btn-success]': '!outline && kind=="success"',
                    '[class.btn-danger]': '!outline && kind=="danger"',
                    '[class.btn-warning]': '!outline && kind=="warning"',
                    '[class.btn-info]': '!outline && kind=="info"',
                    '[class.btn-light]': '!outline && kind=="light"',
                    '[class.btn-dark]': '!outline && kind=="dark"',
                    '[class.btn-link]': 'kind=="link"',
                    '[class.btn-outline-primary]': 'outline && kind=="primary"',
                    '[class.btn-outline-secondary]': 'outline && kind=="secondary"',
                    '[class.btn-outline-success]': 'outline && kind=="success"',
                    '[class.btn-outline-danger]': 'outline && kind=="danger"',
                    '[class.btn-outline-warning]': 'outline && kind=="warning"',
                    '[class.btn-outline-info]': 'outline && kind=="info"',
                    '[class.btn-outline-light]': 'outline && kind=="light"',
                    '[class.btn-outline-dark]': 'outline && kind=="dark"',
                    '[class.btn-sm]': 'size=="small"',
                    '[class.btn-lg]': 'size=="large"',
                    '[attr.disabled]': 'disabled',
                    '[attr.aria-disabled]': 'disabled',
                    '[attr.tabindex]': 'disabled ? "-1" : "" ',
                }
            },] }
];
ButtonDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: Renderer2 }
];
ButtonDirective.propDecorators = {
    disabled: [{ type: Input }],
    size: [{ type: Input }],
    kind: [{ type: Input }],
    safeClick: [{ type: Output }],
    _onClick: [{ type: HostListener, args: ['click', ['$event'],] }]
};

class ButtonModule {
}
ButtonModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    ButtonDirective,
                ],
                exports: [
                    ButtonDirective,
                ]
            },] }
];

class CardFooterDirective {
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
}
CardFooterDirective.decorators = [
    { type: Directive, args: [{
                selector: '[jssCardFooter]',
                exportAs: 'jssCardFooter',
            },] }
];
CardFooterDirective.ctorParameters = () => [
    { type: TemplateRef }
];

class CardHeaderDirective {
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
}
CardHeaderDirective.decorators = [
    { type: Directive, args: [{
                selector: '[jssCardHeader]',
                exportAs: 'jssCardHeader',
            },] }
];
CardHeaderDirective.ctorParameters = () => [
    { type: TemplateRef }
];

class CardComponent {
    constructor(_element, _renderer) {
        this._element = _element;
        this._renderer = _renderer;
    }
    ngOnInit() {
        this._renderer.addClass(this._element.nativeElement, 'card');
    }
}
CardComponent.decorators = [
    { type: Component, args: [{
                selector: 'jss-card',
                exportAs: 'jssCard',
                template: "<div *ngIf=\"_header\" class=\"card-header\">\r\n    <ng-container [ngTemplateOutlet]=\"_header.templateRef\"></ng-container>\r\n</div>\r\n\r\n<div class=\"card-body\">\r\n    <ng-content></ng-content>\r\n</div>\r\n\r\n<div *ngIf=\"_footer\" class=\"card-footer\">\r\n    <ng-container [ngTemplateOutlet]=\"_footer.templateRef\"></ng-container>\r\n</div>\r\n",
                styles: [":host{display:block}"]
            },] }
];
CardComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: Renderer2 }
];
CardComponent.propDecorators = {
    _header: [{ type: ContentChild, args: [CardHeaderDirective,] }],
    _footer: [{ type: ContentChild, args: [CardFooterDirective,] }]
};

const DECLARES = [
    CardComponent,
    CardFooterDirective,
    CardHeaderDirective
];
class CardModule {
}
CardModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: DECLARES,
                exports: DECLARES
            },] }
];

class NavbarCollapseDirective {
    constructor() {
        this.collapsed = true;
    }
}
NavbarCollapseDirective.decorators = [
    { type: Directive, args: [{
                selector: '[jssNavbarCollapse]',
                exportAs: 'jsNavbarCollapse',
                host: {
                    '[class.show]': '!collapsed',
                },
            },] }
];
NavbarCollapseDirective.ctorParameters = () => [];
NavbarCollapseDirective.propDecorators = {
    collapsed: [{ type: Input, args: ['jsNavbarCollapse',] }]
};

class NavbarModule {
}
NavbarModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NavbarCollapseDirective
                ],
                exports: [
                    NavbarCollapseDirective
                ]
            },] }
];

class PopoverWrapperComponent {
    constructor(_elementRef, _renderer) {
        this._elementRef = _elementRef;
        this._renderer = _renderer;
    }
    ngOnInit() {
        const e = this._elementRef.nativeElement;
        this._renderer.setAttribute(e, 'role', 'tooltip');
        this._renderer.setStyle(e, 'margin', '.5rem');
        ['popover', 'fade', 'show'].forEach(c => this._renderer.addClass(e, c));
    }
    get _isStringContent() {
        return typeof this.content === 'string';
    }
    get _cssClass() {
        const r = {};
        r['bs-popover-' + this.placement] = true;
        return r;
    }
}
PopoverWrapperComponent.decorators = [
    { type: Component, args: [{
                selector: 'jss-popover-wrapper',
                exportAs: 'jssPopoverWrapper',
                template: "<div class=\"popover-arrow\"></div>\r\n<h3 class=\"popover-header\">{{title}}</h3>\r\n<div class=\"popover-body\">\r\n    <ng-template [ngIf]=\"_isStringContent\" [ngIfElse]=\"contentTemplate\">{{content}}</ng-template>\r\n\r\n    <ng-template #contentTemplate>\r\n        <ng-container [ngTemplateOutlet]=\"content\"></ng-container>\r\n    </ng-template>\r\n</div>",
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [":host{position:relative}:host.bs-popover-bottom .popover-arrow,:host.bs-popover-top .popover-arrow{left:calc(50% - .5rem)}:host.bs-popover-end .popover-arrow,:host.bs-popover-start .popover-arrow{top:calc(50% - .5rem)}"]
            },] }
];
PopoverWrapperComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: Renderer2 }
];
PopoverWrapperComponent.propDecorators = {
    _cssClass: [{ type: HostBinding, args: ['class',] }]
};

class PopoverDirective {
    constructor(_overlayService, _elementRef, _viewRef) {
        this._overlayService = _overlayService;
        this._elementRef = _elementRef;
        this._viewRef = _viewRef;
        this.placement = 'bottom';
    }
    ngOnInit() {
        this._portal = new ComponentPortal(PopoverWrapperComponent, this._viewRef);
    }
    _onMouseEnter() {
        this._createOverlay();
    }
    _onMouseLeave() {
        this._disposeOverlay();
    }
    _createOverlay() {
        let wrapperInstance;
        const scrollStrategy = this._overlayService.scrollStrategies.reposition();
        const positionStrategy = this._overlayService.position()
            .flexibleConnectedTo(this._elementRef)
            .withPositions(this._getPositions());
        positionStrategy.positionChanges.subscribe(p => {
            wrapperInstance.placement = p.connectionPair.key;
        });
        this._overlayRef = this._overlayService.create({ scrollStrategy, positionStrategy });
        wrapperInstance = this._overlayRef.attach(this._portal).instance;
        wrapperInstance.title = this.title;
        wrapperInstance.content = this.content;
        wrapperInstance.placement = this.placement;
    }
    _getPositions() {
        const c = 'center', t = 'top', b = 'bottom', s = 'start', e = 'end';
        const top = { originX: c, originY: t, overlayX: c, overlayY: b, key: t };
        const bottom = { originX: c, originY: b, overlayX: c, overlayY: t, key: b };
        const start = { originX: s, originY: c, overlayX: e, overlayY: c, key: s };
        const end = { originX: e, originY: c, overlayX: s, overlayY: c, key: e };
        let positions;
        switch (this.placement) {
            case b:
                positions = [bottom, top];
                break;
            case s:
                positions = [start, end];
                break;
            case e:
                positions = [end, start];
                break;
            case t:
                positions = [top, bottom];
                break;
            default:
                positions = [bottom, top];
        }
        return positions;
    }
    _disposeOverlay() {
        if (this._overlayRef) {
            this._overlayRef.dispose();
            this._overlayRef = null;
        }
    }
    ngOnDestroy() {
        this._disposeOverlay();
    }
}
PopoverDirective.decorators = [
    { type: Directive, args: [{
                selector: '[jssPopover]',
                exportAs: 'jssPopover',
            },] }
];
PopoverDirective.ctorParameters = () => [
    { type: Overlay },
    { type: ElementRef },
    { type: ViewContainerRef }
];
PopoverDirective.propDecorators = {
    title: [{ type: Input }],
    content: [{ type: Input, args: ['jssPopover',] }],
    placement: [{ type: Input }],
    _onMouseEnter: [{ type: HostListener, args: ['mouseenter',] }],
    _onMouseLeave: [{ type: HostListener, args: ['mouseleave',] }]
};

class PopoverModule {
    constructor(overlayService) {
        overlayService.injectCss();
    }
}
PopoverModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    PopoverDirective,
                    PopoverWrapperComponent
                ],
                imports: [
                    CommonModule,
                    OverlayModule
                ],
                exports: [
                    PopoverDirective
                ]
            },] }
];
PopoverModule.ctorParameters = () => [
    { type: CdkOverlayService }
];

class TabDirective {
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
}
TabDirective.decorators = [
    { type: Directive, args: [{
                selector: '[jssTab]',
                exportAs: 'jssTab'
            },] }
];
TabDirective.ctorParameters = () => [
    { type: TemplateRef }
];
TabDirective.propDecorators = {
    title: [{ type: Input }],
    disabled: [{ type: Input }]
};

class TabsComponent {
    constructor(_element, _renderer) {
        this._element = _element;
        this._renderer = _renderer;
        this.selectedIndex = 0;
        this.disabled = false;
        this.fade = true;
        this.appearance = 'default';
        this.vertical = false;
        this.tabSelect = new EventEmitter();
    }
    ngOnInit() {
        ['jss-tabs'].forEach(x => this._renderer.addClass(this._element.nativeElement, x));
    }
    _onTabClick(tab, index) {
        if (tab.disabled || this.disabled) {
            return;
        }
        this.selectedIndex = index;
        this.tabSelect.emit({ index, tab });
    }
}
TabsComponent.decorators = [
    { type: Component, args: [{
                selector: 'jss-tabs',
                exportAs: 'jssTabs',
                template: "<ul class=\"nav\"\r\n    [class.nav-tabs]=\"appearance==='default' && !vertical\"\r\n    [class.nav-pills]=\"appearance==='pill' && !vertical\"\r\n    [class.flex-column]=\"vertical\"\r\n    role=\"tablist\">\r\n\r\n    <li *ngFor=\"let tab of tabs; index as i\" class=\"nav-item\" (click)=\"_onTabClick(tab, i)\">\r\n        <button *ngIf=\"!vertical\"\r\n                class=\"nav-link\"\r\n                [class.disabled]=\"tab.disabled || disabled\"\r\n                [class.active]=\"i===selectedIndex\"\r\n                aria-disabled=\"true\"\r\n                role=\"tab\">\r\n            {{tab.title}}\r\n        </button>\r\n\r\n        <a *ngIf=\"vertical\"\r\n           class=\"nav-link\"\r\n           aria-current=\"page\">\r\n            {{tab.title}}\r\n        </a>\r\n    </li>\r\n</ul>\r\n\r\n<div class=\"\" [className]=\"'tab-content ' + (contentCssClass ? contentCssClass : '')\">\r\n    <div *ngFor=\"let tab of tabs; index as i\" class=\"tab-pane\" [class.fade]=\"fade\"\r\n         [class.show]=\"i===selectedIndex\" [class.active]=\"i===selectedIndex\" role=\"tabpanel\">\r\n        <ng-container *ngTemplateOutlet=\"tab.templateRef;\"></ng-container>\r\n    </div>\r\n</div>",
                host: {
                    '[class.jss-tabs-vertical]': 'vertical',
                },
                styles: [":host{display:flex;flex-direction:column}:host.jss-tabs-vertical{flex-direction:row}:host.jss-tabs-vertical .tab-content{flex-grow:1}a{cursor:pointer}"]
            },] }
];
TabsComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: Renderer2 }
];
TabsComponent.propDecorators = {
    tabs: [{ type: ContentChildren, args: [TabDirective,] }],
    selectedIndex: [{ type: Input }],
    disabled: [{ type: Input }],
    fade: [{ type: Input }],
    appearance: [{ type: Input }],
    vertical: [{ type: Input }],
    contentCssClass: [{ type: Input }],
    tabSelect: [{ type: Output }]
};

const DECLARES$1 = [
    TabsComponent,
    TabDirective
];
class TabsModule {
}
TabsModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                ],
                declarations: DECLARES$1,
                exports: DECLARES$1
            },] }
];

class TooltipWrapperComponent {
    constructor(_elementRef, _renderer) {
        this._elementRef = _elementRef;
        this._renderer = _renderer;
    }
    ngOnInit() {
        const elm = this._elementRef.nativeElement;
        this._renderer.setAttribute(elm, 'role', 'tooltip');
        ['tooltip', 'fade', 'show'].forEach(c => this._renderer.addClass(elm, c));
    }
    get _isStringContent() {
        return typeof this.content === 'string';
    }
    get _cssClass() {
        const r = {};
        r['bs-tooltip-' + this.placement] = true;
        return r;
    }
}
TooltipWrapperComponent.decorators = [
    { type: Component, args: [{
                selector: 'jss-tooltip-wrapper',
                exportAs: 'jssTooltipWrapper',
                template: "<div class=\"tooltip-arrow\"></div>\r\n<div class=\"tooltip-inner\">\r\n    <ng-template [ngIf]=\"_isStringContent\" [ngIfElse]=\"contentTemplate\">{{content}}</ng-template>\r\n\r\n    <ng-template #contentTemplate>\r\n        <ng-container [ngTemplateOutlet]=\"content\"></ng-container>\r\n    </ng-template>\r\n</div>",
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [":host{position:relative}:host.bs-tooltip-bottom .tooltip-arrow,:host.bs-tooltip-top .tooltip-arrow{left:calc(50% - .5rem)}:host.bs-tooltip-end .tooltip-arrow,:host.bs-tooltip-start .tooltip-arrow{top:calc(50% - .5rem)}"]
            },] }
];
TooltipWrapperComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: Renderer2 }
];
TooltipWrapperComponent.propDecorators = {
    _cssClass: [{ type: HostBinding, args: ['class',] }]
};

class TooltipDirective {
    constructor(_overlayService, _elementRef, _viewRef) {
        this._overlayService = _overlayService;
        this._elementRef = _elementRef;
        this._viewRef = _viewRef;
        this.placement = 'bottom';
    }
    ngOnInit() {
        this._portal = new ComponentPortal(TooltipWrapperComponent, this._viewRef);
    }
    _onMouseEnter() {
        this._createOverlay();
    }
    _onMouseLeave() {
        this._disposeOverlay();
    }
    _createOverlay() {
        let wrapperInstance;
        const scrollStrategy = this._overlayService.scrollStrategies.reposition();
        const positionStrategy = this._overlayService.position()
            .flexibleConnectedTo(this._elementRef)
            .withPositions(this._getPositions());
        positionStrategy.positionChanges.subscribe(p => {
            wrapperInstance.placement = p.connectionPair.key;
        });
        this._overlayRef = this._overlayService.create({ scrollStrategy, positionStrategy });
        wrapperInstance = this._overlayRef.attach(this._portal).instance;
        wrapperInstance.content = this.content;
        wrapperInstance.placement = this.placement;
    }
    _getPositions() {
        const c = 'center', t = 'top', b = 'bottom', s = 'start', e = 'end';
        const top = { originX: c, originY: t, overlayX: c, overlayY: b, key: t };
        const bottom = { originX: c, originY: b, overlayX: c, overlayY: t, key: b };
        const start = { originX: s, originY: c, overlayX: e, overlayY: c, key: s };
        const end = { originX: e, originY: c, overlayX: s, overlayY: c, key: e };
        let positions;
        switch (this.placement) {
            case 'bottom':
                positions = [bottom, top];
                break;
            case 'start':
                positions = [start, start];
                break;
            case 'end':
                positions = [end, start];
                break;
            case 'top':
                positions = [top, bottom];
                break;
            default:
                positions = [bottom, top];
        }
        return positions;
    }
    _disposeOverlay() {
        if (this._overlayRef) {
            this._overlayRef.dispose();
            this._overlayRef = null;
        }
    }
    ngOnDestroy() {
        this._disposeOverlay();
    }
}
TooltipDirective.decorators = [
    { type: Directive, args: [{
                selector: '[jssTooltip]',
                exportAs: 'jssTooltip',
            },] }
];
TooltipDirective.ctorParameters = () => [
    { type: Overlay },
    { type: ElementRef },
    { type: ViewContainerRef }
];
TooltipDirective.propDecorators = {
    content: [{ type: Input, args: ['jssTooltip',] }],
    placement: [{ type: Input }],
    _onMouseEnter: [{ type: HostListener, args: ['mouseenter',] }],
    _onMouseLeave: [{ type: HostListener, args: ['mouseleave',] }]
};

class TooltipModule {
    constructor(overlayService) {
        overlayService.injectCss();
    }
}
TooltipModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    TooltipDirective,
                    TooltipWrapperComponent
                ],
                imports: [
                    CommonModule,
                    OverlayModule
                ],
                exports: [
                    TooltipDirective
                ]
            },] }
];
TooltipModule.ctorParameters = () => [
    { type: CdkOverlayService }
];

export { BadgeDirective, BadgeModule, BreadcrumbComponent, BreadcrumbItemTemplateDirective, BreadcrumbModule, ButtonDirective, ButtonModule, CardComponent, CardFooterDirective, CardHeaderDirective, CardModule, NavbarCollapseDirective, NavbarModule, PopoverDirective, PopoverModule, PopoverWrapperComponent, TabDirective, TabsComponent, TabsModule, TooltipDirective, TooltipModule, TooltipWrapperComponent };
//# sourceMappingURL=js-sugar-angular-bootstrap.js.map
